// 
// Copyright 2010 eviware software ab
// 
// Licensed under the EUPL, Version 1.1 or - as soon they will be approved by the European Commission - subsequent
// versions of the EUPL (the "Licence");
// You may not use this work except in compliance with the Licence.
// You may obtain a copy of the Licence at:
// 
// http://ec.europa.eu/idabc/eupl5
// 
// Unless required by applicable law or agreed to in writing, software distributed under the Licence is
// distributed on an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
// express or implied. See the Licence for the specific language governing permissions and limitations
// under the Licence.
// 

/**
 * Dispatches incoming messages based on their HttpStatus to a configured Output
 * 
 * @name HTTP StatusCode Splitter
 * @category Flow
 * @nonBlocking true
 */
 
import com.eviware.loadui.api.events.PropertyEvent

createProperty( 'codes', String, '1??,2??,3??,4??,5??' )

def codeMap = [:]

onMessage = { incoming, outgoing, message ->

	def status = message["HttpStatus"]
	if( status != null )
	{
		status = String.valueOf( status )
		codeMap.each
		{ 
			def v = it.key
			if( status.length() == v.length() )
			{
				def c = 0
				for( ; c < status.length(); c++ )
				{
					if( v.charAt( c ) != status.charAt( c ) && v.charAt( c ) != '?'  )
						break
				}
				
				if( c == status.length() )
				   send( it.value, message )
			}
		}
	}
}

addEventListener( PropertyEvent ) { event ->
	if ( event.event == PropertyEvent.Event.VALUE ) {
		if( event.property == codes ) {
			applyCodes()
		}
	}
}

applyCodes =
{
	codeMap.each{ deleteTerminal( it.value ) }
	codeMap.clear()
	
	def v = codes.value
	if( v.length() > 0 )
	{
		for( s in v.split( "," ))
		{
			codeMap.put( s.trim(), createOutput( s.trim() ))
		}
	}
}

applyCodes()

//Layout
layout { 
	property( property:codes, label:'HTTP Codes', constraints: 'w 200!' ) 
}